/* TMut
 * Copyright (C) 2006-2007 Philip Van Hoof <pvanhoof@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with self library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#if HAVE_CONFIG_H
#include "config.h"
#endif

#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>

#include <tny-account-store.h>
#include <tny-account-store-view.h>


#include "tmut-platform-factory.h"
#include "tmut-menu-view.h"
#include "tmut-shell-window.h"

TnyPlatformFactory *platfact = NULL;
GHashTable *send_queues = NULL;

int 
main (int argc, char **argv)
{
	GtkWidget *window;
	TnyAccountStore *account_store;
	TnyAccountStoreView *view;

	if (!g_thread_supported ()) 
		g_thread_init (NULL);

	gdk_threads_init ();

	gdk_threads_enter ();
	gtk_init (&argc, &argv);

	bindtextdomain(GETTEXT_PACKAGE, TMUT_LOCALE_DIR);

	window = GTK_WIDGET (tmut_shell_window_new ());
	gtk_window_set_title (GTK_WINDOW (window), _("TMut"));

	platfact = tmut_platform_factory_get_instance ();
	account_store = tny_platform_factory_new_account_store (platfact);

	view = TNY_ACCOUNT_STORE_VIEW (tmut_menu_view_new ());
	gtk_widget_show (GTK_WIDGET (view));

	tmut_shell_window_set_child (TMUT_SHELL_WINDOW (window), 
		TMUT_SHELL_CHILD (view), NULL);

	tny_account_store_view_set_account_store (view, account_store);

	g_signal_connect (window, "destroy", G_CALLBACK (gtk_main_quit), 0);

	gtk_widget_show (window);

	gtk_main();
	gdk_threads_leave ();

	return 0;
}


gchar *
_get_readable_date (time_t mtime)
{
	time_t now;
	struct tm file_time;

	/** 
	 * We reuse a static char. Now hold your breath and listen. This is not
	 * wrong and I'll explain why: each component that uses this function
	 * is called from the Gtk+ context. The Gtk+ context can never run in
	 * parallel with another context because Gtk+ is locked using its
	 * gdk_threads_enter/leave lock. This means that there's always at most
	 * one thread doing Gtk+ things. This means that this function does not
	 * have to be thread safe. And that means that we can have a static 
	 * buffer that we'll play with. Else we could also do a pthread_once 
	 * or something. 
	 *
	 * I here the children cry things like: waaayyyy?? Well the reason is to
	 * avoid a malloc(). This stuff happens quite often. If we can reuse one
	 * buffer each time, that's fine! The GtkTreeView (if this time that is
	 * consumer)  makes its own copy. Same for any other Gtk+ component that
	 * accepts strings (like a GtkEntry or a GtkLabel). It will make its own
	 * copy anyway! If we are going to copy here, that's two copies rather 
	 * than just the one copy in Gtk+ that we have no control over.
	 **/

	static gchar readable_date[64];

	gsize readable_date_size;
	int days_now, days_then;

	gmtime_r (&mtime, &file_time);
	now = time (NULL); 

	/* The idea is that if the amount of days is not the same, we display
	 * the full date. Else we just display the time. Note that there's a
	 * hidden bug in this: days_then is the remote timezone, days_now is the
	 * local timezone. At some point we should fix this! */

	days_now = now / (24*60*60);
	days_then = mtime / (24*60*60);

	/* I think we can fix this using localtime_r */

	if (days_now == days_then) { 
		/* Translator: this date-format is the date format for when creating a
		 * reply of a message if the date is today */
		readable_date_size = strftime (readable_date, 63, _("%X"), &file_time);
	} else { 
		/* Translator: this date-format is the date format for when creating a
		 * reply of a message if the date is not today */
		readable_date_size = strftime (readable_date, 63, _("%x"), &file_time);
	}

	if (readable_date_size > 0)
		return readable_date;

	return NULL;
}
