/* TMut
 * Copyright (C) 2006-2007 Philip Van Hoof <pvanhoof@gnome.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with self library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#if HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib/gi18n-lib.h>

#include "tmut-ringtone-player.h"

static GObjectClass *parent_class = NULL;

static void
tmut_ringtone_player_play_ringtone (TnyFolderObserver *self, TMutRingtone ringtone)
{
	switch (ringtone) 
	{
		case TMUT_RINGTONE_NEW_MESSAGE:
		default:
		g_printf (_("Play ringtone\n"));
		break;
	}
}

static void
tmut_ringtone_player_update (TnyFolderObserver *self, TnyFolderChange *change)
{
	TnyFolderChangeChanged changed = tny_folder_change_get_changed (change);

	if (changed & TNY_FOLDER_CHANGE_CHANGED_ADDED_HEADERS)
		tmut_ringtone_player_play_ringtone (self, TMUT_RINGTONE_NEW_MESSAGE);

	return;
}

/**
 * tmut_ringtone_player_new:
 * @folder: a #TMutFolder instance
 *
 * Creates a folder monitor for @folder
 *
 * Return value: a new #TMutRingtonePlayer instance
 **/
TnyFolderObserver*
tmut_ringtone_player_new (void)
{
	TMutRingtonePlayer *self = g_object_new (TMUT_TYPE_RINGTONE_PLAYER, NULL);

	return TNY_FOLDER_OBSERVER (self);
}


static void
tmut_ringtone_player_finalize (GObject *object)
{
	parent_class->finalize (object);
}

static void
tmut_ringtone_player_instance_init (GTypeInstance *instance, gpointer g_class)
{
	return;
}

static void
tny_folder_observer_init (TnyFolderObserverIface *klass)
{
	klass->update_func = tmut_ringtone_player_update;
}

static void
tmut_ringtone_player_class_init (TMutRingtonePlayerClass *klass)
{
	GObjectClass *object_class;

	parent_class = g_type_class_peek_parent (klass);
	object_class = (GObjectClass*) klass;

	object_class->finalize = tmut_ringtone_player_finalize;
}

GType
tmut_ringtone_player_get_type (void)
{
	static GType type = 0;
	if (G_UNLIKELY(type == 0))
	{
		static const GTypeInfo info = 
		{
			sizeof (TMutRingtonePlayerClass),
			NULL,   /* base_init */
			NULL,   /* base_finalize */
			(GClassInitFunc) tmut_ringtone_player_class_init,   /* class_init */
			NULL,   /* class_finalize */
			NULL,   /* class_data */
			sizeof (TMutRingtonePlayer),
			0,      /* n_preallocs */
			tmut_ringtone_player_instance_init,    /* instance_init */
			NULL
		};


		static const GInterfaceInfo tny_folder_observer_info = 
		{
			(GInterfaceInitFunc) tny_folder_observer_init, /* interface_init */
			NULL,         /* interface_finalize */
			NULL          /* interface_data */
		};

		type = g_type_register_static (G_TYPE_OBJECT,
			"TMutRingtonePlayer",
			&info, 0);

		g_type_add_interface_static (type, TNY_TYPE_FOLDER_OBSERVER,
			&tny_folder_observer_info);

	}
	return type;
}
